==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/live/v20180801/models/DeleteLiveCertRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteLiveCertRequest extends AbstractModel{

    /**
    * DescribeLiveCerts接口获取到的证书Id。
    */
    @SerializedName("CertId")
    @Expose
    private Long CertId;

    /**
     * Get DescribeLiveCerts接口获取到的证书Id。 
     * @return CertId DescribeLiveCerts接口获取到的证书Id。
     */
    public Long getCertId() {
        return this.CertId;
    }

    /**
     * Set DescribeLiveCerts接口获取到的证书Id。
     * @param CertId DescribeLiveCerts接口获取到的证书Id。
     */
    public void setCertId(Long CertId) {
        this.CertId = CertId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CertId", this.CertId);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/live/v20180801/models/DeleteLiveCertRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteLiveCertRequest extends AbstractModel{

    /**
    * DescribeLiveCerts接口获取到的证书Id。
    */
    @SerializedName("CertId")
    @Expose
    private Long CertId;

    /**
     * Get DescribeLiveCerts接口获取到的证书Id。 
     * @return CertId DescribeLiveCerts接口获取到的证书Id。
     */
    public Long getCertId() {
        return this.CertId;
    }

    /**
     * Set DescribeLiveCerts接口获取到的证书Id。
     * @param CertId DescribeLiveCerts接口获取到的证书Id。
     */
    public void setCertId(Long CertId) {
        this.CertId = CertId;
    }

    public DeleteLiveCertRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteLiveCertRequest(DeleteLiveCertRequest source) {
        if (source.CertId != null) {
            this.CertId = new Long(source.CertId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CertId", this.CertId);

    }
}
